@@ -1,3 +1,4 @@
+# $Id$
 package Module::Release;
 
 =head1 NAME
@@ -22,10 +23,9 @@ use warnings;
 no warnings;
 use vars qw($VERSION);
 
-$VERSION = '2.05_02';
+$VERSION = '2.01';
 
 use Carp;
-use File::Basename qw(dirname);
 use File::Spec;
 use Scalar::Util qw(blessed);
 
@@ -131,10 +131,6 @@ Your SourceForge account (i.e. login) name.
 
 Set this to a true value to enable passive FTP.
 
-=item ignore_prereqs
-
-A whitespace separated list of modules for C<Test::Prereq> to ignore.
-
 =back
 
 =head2 Methods
@@ -169,7 +165,6 @@ sub new
 
 	if( $config->release_subclass )
 		{
-		$self->_warn( "Use of release_subclass is deprecated" );
 		$self->_die( "release_subclass is the same class! Don't do that!" )
 			if $config->release_subclass eq $class;
 		my $subclass_self = $self->_handle_subclass(
@@ -186,19 +181,12 @@ sub new
 
 =item init()
 
-Set up the C<Module::Release> object. By default, it expects something
-using MakeMaker, but if it sees a F<Build.PL> it configures itself for
-C<Module::Build>.
-
-The values in the configuration file override any settings here, so if you
-have both a F<Makefile.PL> and a F<Build.PL> then you can override the
-C<Module::Build> preference by setting the C<makefile_PL> and C<make>
-configuration values.
+Set up the C<Module::Release> object.
 
 =cut
 
 sub init
-	{
+	{	
 	my( $self, $config, %params ) = @_;
 
 	$self->_set_defaults( %params );
@@ -221,19 +209,17 @@ sub _set_defaults
 	my( $self, %params ) = @_;
 
 	my $defaults = {
-			'Makefile.PL'  => 'Makefile.PL',
-			'Makefile'     => 'Makefile',
-			make           => $Config::Config{make},
-			manifest       => 'MANIFEST',
-			debug          => $ENV{RELEASE_DEBUG} || 0,
-			local_file     => undef,
-			remote_file    => undef,
-			output_fh      => *STDOUT{IO},
-			debug_fh       => *STDERR{IO},
-			null_fh        => IO::Null->new(),
-			quiet          => 0,
-			devnull        => File::Spec->devnull,
-			ignore_prereqs => '',
+			'Makefile.PL' => 'Makefile.PL',
+			'Makefile'    => 'Makefile',
+			make          => $Config::Config{make},
+			manifest      => 'MANIFEST',
+			debug         => $ENV{RELEASE_DEBUG} || 0,
+			local_file    => undef,
+			remote_file   => undef,
+			output_fh     => *STDOUT{IO},
+			debug_fh      => *STDERR{IO},
+			null_fh       => IO::Null->new(),
+			quiet         => 0,
 
 			%params,
 		   };
@@ -246,16 +232,6 @@ sub _set_defaults
 	$self->set_perl( $^X );
 	$self->add_a_perl( $^X );
 
-	# setup for Module::Build. This is a kludge. There isn't a
-	# programmatic interface to Makemaker, and I don't want to
-	# treat Makemaker and Module::Build differently. I'm stuck
-	# with a fancy shell script.
-	if( -e 'Build.PL' )
-		{
-		$self->{'make'}        = File::Spec->catfile(qw{. Build});
-		$self->{'Makefile.PL'} = 'Build.PL';
-		$self->{'Makefile'}    = '_build';
-		}
 	1;
 	}
 
@@ -289,24 +265,6 @@ sub _process_configuration
 	$self->{passive_ftp} =
 		($self->config->passive_ftp && $self->config->passive_ftp =~ /^y(es)?/) ? 1 : 0;
 
-
-	{
-	my @pairs = (
-		[ qw(Makefile.PL makefile_PL) ],
-		[ qw(Makefile    makefile)    ],
-		[ qw(make        make)        ],
-		);
-
-	foreach my $pair ( @pairs )
-		{
-		my( $key, $config ) = @$pair;
-
-		$self->{$key} = $self->config->get($config)
-			if $self->config->exists($config);
-		}
-	}
-
-
 	my @required = qw(  );
 
 	my $ok = 1;
@@ -382,7 +340,7 @@ sub load_mixin
 	return 1 if $self->mixin_loaded( $module );
 
 	no warnings 'redefine';
-
+	
 	eval "use $module";
 
 	$self->_die( "Could not load [$module]! $@" ) if $@;
@@ -437,7 +395,7 @@ sub get_web_user_agent { $_[0]->{web_user_agent} || $_[0]->setup_web_user_agent
 Create a web user agent and store it in the object. Get a reference to it
 by saving the result or calling C<get_web_user_agent>. If you call this
 method again, it replaces the internal web user agent (and anything you've
-done to it since you first set it up). It passes any arguments to the
+done to it since you first set it up). It passes any arguments to the 
 constructor of the user agent class.
 
 It calls C<web_user_agent_name> to set the initial agent name, and sets
@@ -445,17 +403,17 @@ up an empty, in-memory cookie jar.
 
 =cut
 
-sub setup_web_user_agent
+sub setup_web_user_agent 
 	{
 	my $self = shift;
-
+	
 	my $class = $self->web_user_agent_class;
 	my $rc = eval { eval "require $class" };
 	unless( $rc ) { $self->_die( "Could not load $class: $@" ) };
-
-	my $ua = $self->web_user_agent_class->new(
+	
+	my $ua = $self->web_user_agent_class->new( 
 		agent => $self->web_user_agent_name,
-		@_
+		@_ 
 		);
 
 	$ua->cookie_jar( {} );
@@ -473,7 +431,7 @@ sub web_user_agent_class { 'LWP::UserAgent' }
 
 =item web_user_agent_name
 
-The user agent name to use with web requests. Let's just call that
+The user agent name to use with web requests. Let's just call that 
 C<Mozilla> for now.
 
 =cut
@@ -548,6 +506,7 @@ sub _looks_like_perl
 	{
 	my( $self, $path ) = @_;
 
+
 	my $version = `$path -e "print \$\]" 2>&1`;
 
 	$version =~ m/^\d+\.[\d_]+$/ ? $version : ();
@@ -602,14 +561,6 @@ sub add_a_perl
 	unless( -x $path )
 		{
 		$self->_warn( "$path is not executable" );
-		if( $path =~ m/[*?[]/ && $self->config->allow_glob_in_perls )
-			{
-			$self->add_a_perl( $_ ) for glob $path;
-			}
-		else
-			{
-			$self->_warn( "$path is not executable" );
-			}
 		return;
 		}
 
@@ -850,28 +801,8 @@ sub test
 
 	my $tests = $self->run( "$self->{make} test 2>&1" );
 
-	unless ($tests =~ m/All tests successful/) {
-		if( $self->debug ) { # from H.Merijn Brand
-			my $prove = File::Spec->catfile(
-				dirname( $self->get_perl ),
-				'prove'
-				);
-
-			if( -x $prove ) {
-				my $prove_out =
-					join "\n\n",
-					map { scalar qx"$prove -wvb $_" }
-                    ($tests =~ m{^(t/\w+\.t)\s+[0-9]+}gm);
-				$prove_out =~ s/^.*\r//gm;
-				$self->_warn( $prove_out );
-				}
-			elsif( $self->debug ) {
-				$self->_print( "prove [$prove] was not executable!" );
-				}
-			}
-
-          $self->_die( "\nERROR: Tests failed!\n$tests\n\nAborting release\n" )
-          }
+	$self->_die( "\nERROR: Tests failed!\n$tests\n\nAborting release\n" )
+		    unless $tests =~ /All tests successful/;
 
 	$self->_print( "all tests pass\n" );
 	}
@@ -888,17 +819,22 @@ sub dist
 	my $self = shift;
 	$self->_print( "Making dist... " );
 
-	$self->build_makefile;
+	unless( -e $self->{'Makefile'} )
+		{
+		$self->_debug( "no Makefle, so skipping" );
+		$self->_print( " no $self->{'Makefile'}---skipping\n" );
+		return;
+		}
 
-	my $messages = $self->run( "$self->{make} dist 2>&1 < $self->{devnull}" );
-	$self->_debug( "messages are [$messages]\n" );
+	my $messages = $self->run( "$self->{make} dist 2>&1 < /dev/null" );
+	$self->_debug( "messages are [$messages]" );
 
 	# If the distro isn't already set, try to guess it
 	unless( $self->local_file )
 		{
-		$self->_debug( ", guessing local distribution name\n" );
-		my( $guess ) = $messages =~ /(?:\s|')(\S+\.tar)/;
-		$self->_debug( "guessed [$guess]\n" );
+		$self->_debug( ", guessing local distribution name" );
+		my( $guess ) = $messages =~ /^\s*gzip.+?\b'?(\S+\.tar)'?\s*$/m;
+		$self->_debug( "guessed [$guess]" );
 		$self->local_file( $guess );
 
 		$self->_die( "Couldn't guess distname from dist output\n" )
@@ -1076,9 +1012,9 @@ deprecated.
 
 sub manifest_name { 'MANIFEST' }
 
-sub manifest {
+sub manifest { 
 	$_[0]->_warn( "manifest is deprecated. Use manifest_name" );
-	&manifest_name
+	&manifest_name 
 	}
 
 =item files_in_manifest
@@ -1090,14 +1026,14 @@ Return the filenames in the manifest file as a list.
 sub files_in_manifest
 	{
 	my $self = shift;
-
+	
 	require ExtUtils::Manifest;
-
+	
 	# I want to use ExtUtils::Manifest so it automatically
 	# follows the right MANIFEST rules, but I have to adapt
 	# it's output to my output. Annoying, for sure.
 	my $hash = do {
-		local $SIG{'__WARN__'} = sub {
+		local $SIG{'__WARN__'} = sub { 
 			my $message = shift;
 			if( $message =~ m/Debug: (.*)/ )
 				{
@@ -1108,10 +1044,10 @@ sub files_in_manifest
 				$self->_die( "files_in_manifest: could not open file\n" );
 				}
 			};
-
+			
 		ExtUtils::Manifest::maniread( $self->manifest_name );
 		};
-
+	
 	sort keys %$hash;
 	}
 
@@ -1166,7 +1102,7 @@ Returns the number of files which it successfully touched.
 sub touch
 	{
 	my( $self, @files ) = @_;
-
+	
 	my $time = time;
 
 	my $count = 0;
@@ -1221,9 +1157,9 @@ sub check_for_passwords
 	{
 	if( my $pass = $_[0]->config->cpan_user && $_[0]->get_env_var( "CPAN_PASS" )  )
 		{
-		$_[0]->config->set( 'cpan_pass', $pass );
+		$_[0]->config->set( 'cpan_pass', $pass ); 
 		}
-
+		
 	$_[0]->_debug( "CPAN pass is " . $_[0]->config->cpan_pass );
 	}
 
@@ -1293,7 +1229,7 @@ sub run
 
 	$self->_debug( "$command\n" );
 	$self->_die( "Didn't get a command!" ) unless defined $command;
-
+	
 	open my($fh), "$command |" or $self->_die( "Could not open command [$command]: $!" );
 	$fh->autoflush;
 
@@ -1406,12 +1342,10 @@ module form.
 Andy Lester handled the maintenance while I was on my Big Camping
 Trip. He applied patches from many authors.
 
-Andreas König suggested changes to make it work better with PAUSE.
+Andreas KE<ouml>nig suggested changes to make it work better with PAUSE.
 
 Chris Nandor helped with figuring out the broken SourceForge stuff.
 
-H.Merijn Brand has contributed many patches and features.
-
 =head1 SOURCE AVAILABILITY
 
 This source is in Github:
@@ -1424,7 +1358,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2011 brian d foy.  All rights reserved.
+Copyright (c) 2002-2008 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -1432,3 +1366,5 @@ it under the same terms as Perl itself.
 =cut
 
 1;
+
+__END__
