@@ -1,3 +1,4 @@
+# $Id$
 package Module::Release::SVN;
 
 use strict;
@@ -9,7 +10,7 @@ use Carp;
 
 our @EXPORT = qw(check_vcs vcs_tag make_vcs_tag);
 
-$VERSION = '2.05_02';
+$VERSION = '2.01';
 
 =head1 NAME
 
@@ -52,7 +53,7 @@ sub check_cvs
 	carp "check_cvs is deprecated in favor of check_vcs. Update your programs!";
 	&check_vcs;
 	}
-
+	
 sub check_vcs
 	{
 	my $self = shift;
@@ -70,13 +71,13 @@ sub check_vcs
 	$svn_update =~ s/^(........)\s+\d+\s+\d+\s+\S+\s+(.*)$/$1 $2/mg;
 
 	my %message = (
-		qr/^C......./m   => 'These files have conflicts',
-		qr/^M......./m   => 'These files have not been checked in',
-		qr/^........\*/m => 'These files need to be updated',
-		qr/^P......./m   => 'These files need to be patched',
-		qr/^A......./m   => 'These files were added but not checked in',
-		qr/^D......./m   => 'These files are scheduled for deletion',
-		qr/^\?......./m  => 'I don\'t know about these files',
+		qr/^C......./   => 'These files have conflicts',
+		qr/^M......./   => 'These files have not been checked in',
+		qr/^........\*/ => 'These files need to be updated',
+		qr/^P......./   => 'These files need to be patched',
+		qr/^A......./   => 'These files were added but not checked in',
+		qr/^D......./   => 'These files are scheduled for deletion',
+		qr/^\?......./  => 'I don\'t know about these files',
 		);
 
 	my @svn_states = keys %message;
@@ -84,7 +85,7 @@ sub check_vcs
 	my %svn_state;
 	foreach my $state (@svn_states)
 		{
-		$svn_state{$state} = [ $svn_update =~ /$state\s+(.*)/g ];
+		$svn_state{$state} = [ $svn_update =~ /$state\s+(.*)/gm ];
 		}
 
 	my $count;
@@ -135,7 +136,7 @@ sub cvs_tag
 	carp "cvs_tag is deprecated in favor of vcs_tag. Update your programs!";
 	&check_vcs;
 	}
-
+	
 sub vcs_tag
 	{
 	require URI;
@@ -199,13 +200,13 @@ sub vcs_tag
 		return;
 		}
 
-	my $tag = $self->make_vcs_tag;
+	my $tag = $self->make_cvs_tag;
 
 	push @tag_url, $tag;
 	$tag_url->path_segments(@tag_url);
 	$self->_print( "Tagging release to $tag_url\n" );
 
-	$self->run( "svn copy $trunk_url $tag_url" );
+	$self->run( 'svn copy $trunk_url $tag_url' );
 
 	if ( $? )
 		{
@@ -238,7 +239,7 @@ sub make_cvs_tag
 	carp "make_cvs_tag is deprecated in favor of make_vcs_tag. Update your programs!";
 	&make_vcs_tag;
 	}
-
+	
 sub make_vcs_tag
 	{
 	my $self = shift;
@@ -266,7 +267,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2011, brian d foy, All Rights Reserved.
+Copyright (c) 2007-2008, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
